@@ -1,26 +1,20 @@
-from typing import List
-
 import numpy as np
+from evobench.model.solution import Solution
+from evobench.benchmark import Benchmark
+from evobench.util import shuffle
 from lazy import lazy
 
-from evobench.model.solution import Solution
-from evobench.separable import Separable
 
-
-class Discrete(Separable):
+class Discrete(Benchmark):
 
     def __init__(
         self,
-        blocks: List[int],
-        overlap_size: int = 0,
-        shuffle: bool = False,
+        use_shuffle: bool = False,
         multiprocessing: bool = False,
         verbose: int = 0
     ):
         super(Discrete, self).__init__(
-            blocks,
-            overlap_size,
-            shuffle,
+            use_shuffle,
             multiprocessing,
             verbose
         )
@@ -48,4 +42,7 @@ class Discrete(Separable):
         genome -= self.lower_bound
         genome = genome.astype(dtype=np.int)
 
+        if self.USE_SHUFFLE:
+            genome = shuffle(genome, self.gene_order)
+
         return Solution(genome)
